@@ -1030,7 +1030,7 @@ pygobject__g_instance_init(GTypeInstance   *instance,
                            gpointer         g_class)
 {
     GObject *object = (GObject *) instance;
-    PyObject *wrapper, *args, *kwargs;
+    PyObject *wrapper, *result;
     PyGILState_STATE state;
 
     wrapper = g_object_get_qdata(object, pygobject_wrapper_key);
@@ -1057,18 +1057,16 @@ pygobject__g_instance_init(GTypeInstance   *instance,
          * so we don't destroy the wrapper. The next call to pygobject_new_full
          * will take the ref */
         pygobject_ref_float ((PyGObject *) wrapper);
-        args = PyTuple_New(0);
-        kwargs = PyDict_New();
-        if (Py_TYPE(wrapper)->tp_init(wrapper, args, kwargs))
-            PyErr_Print();
 
-        Py_DECREF(args);
-        Py_DECREF(kwargs);
+        result = PyObject_CallMethod (wrapper, "__init__", NULL);
+        if (result == NULL)
+            PyErr_Print ();
+        else
+            Py_DECREF (result);
     }
 
     /* XXX: used for Gtk.Template */
     if (PyObject_HasAttrString (wrapper, "__dontuse_ginstance_init__")) {
-        PyObject *result;
         result = PyObject_CallMethod (wrapper, "__dontuse_ginstance_init__", NULL);
         if (result == NULL)
             PyErr_Print ();
@@ -1887,12 +1885,6 @@ _wrap_pyg_variant_type_from_string (PyObject *self, PyObject *args)
     return py_variant;
 }
 
-static PyObject *
-_wrap_pyg_source_new (PyObject *self, PyObject *args)
-{
-    return pyg_source_new ();
-}
-
 #define CHUNK_SIZE 8192
 
 static PyObject*
@@ -2246,7 +2238,34 @@ _wrap_pyig_pyos_getsig (PyObject *self, PyObject *args)
     return PyLong_FromVoidPtr ((void *)(PyOS_getsig (sig_num)));
 }
 
+static PyObject *
+_wrap_pygobject_new_full (PyObject *self, PyObject *args)
+{
+    PyObject *ptr_value, *long_value;
+    PyObject *steal;
+    GObject *obj;
+
+    if (!PyArg_ParseTuple (args, "OO", &ptr_value, &steal))
+        return NULL;
+
+    long_value = PyNumber_Long (ptr_value);
+    if (!long_value) {
+        PyErr_SetString (PyExc_TypeError, "first argument must be an integer");
+        return NULL;
+    }
+    obj = PyLong_AsVoidPtr (long_value);
+    Py_DECREF (long_value);
+
+    if (!G_IS_OBJECT (obj)) {
+        PyErr_SetString (PyExc_TypeError, "pointer is not a GObject");
+        return NULL;
+    }
+
+    return pygobject_new_full (obj, PyObject_IsTrue (steal), NULL);
+}
+
 static PyMethodDef _gi_functions[] = {
+    { "pygobject_new_full", (PyCFunction) _wrap_pygobject_new_full, METH_VARARGS },
     { "enum_add", (PyCFunction) _wrap_pyg_enum_add, METH_VARARGS | METH_KEYWORDS },
     { "enum_register_new_gtype_and_add", (PyCFunction) _wrap_pyg_enum_register_new_gtype_and_add, METH_VARARGS | METH_KEYWORDS },
     { "flags_add", (PyCFunction) _wrap_pyg_flags_add, METH_VARARGS | METH_KEYWORDS },
@@ -2255,9 +2274,9 @@ static PyMethodDef _gi_functions[] = {
     { "register_interface_info", (PyCFunction) _wrap_pyg_register_interface_info, METH_VARARGS },
     { "hook_up_vfunc_implementation", (PyCFunction) _wrap_pyg_hook_up_vfunc_implementation, METH_VARARGS },
     { "variant_type_from_string", (PyCFunction) _wrap_pyg_variant_type_from_string, METH_VARARGS },
-    { "source_new", (PyCFunction) _wrap_pyg_source_new, METH_NOARGS },
+    { "source_new", (PyCFunction) pygi_source_new, METH_NOARGS },
     { "pyos_getsig", (PyCFunction) _wrap_pyig_pyos_getsig, METH_VARARGS },
-    { "source_set_callback", (PyCFunction) pyg_source_set_callback, METH_VARARGS },
+    { "source_set_callback", (PyCFunction) pygi_source_set_callback, METH_VARARGS },
     { "io_channel_read", (PyCFunction) pyg_channel_read, METH_VARARGS },
     { "require_foreign", (PyCFunction) pygi_require_foreign, METH_VARARGS | METH_KEYWORDS },
     { "spawn_async",
@@ -2380,7 +2399,7 @@ pygi_register_api(PyObject *d)
 {
     PyObject *api;
 
-    api = PYGLIB_CPointer_WrapPointer(&pygobject_api_functions, "gobject._PyGObject_API");
+    api = PyCapsule_New (&pygobject_api_functions, "gobject._PyGObject_API", NULL);
     if (api == NULL)
         return -1;
     PyDict_SetItemString(d, "_PyGObject_API", api);
@@ -2533,7 +2552,7 @@ PYGLIB_MODULE_START(_gi, "_gi")
     Py_INCREF(PyGIDeprecationWarning);
     PyModule_AddObject(module, "PyGIDeprecationWarning", PyGIDeprecationWarning);
 
-    api = PYGLIB_CPointer_WrapPointer ( (void *) &CAPI, "gi._API");
+    api = PyCapsule_New ( (void *) &CAPI, "gi._API", NULL);
     if (api == NULL) {
         return PYGLIB_MODULE_ERROR_RETURN;
     }
